@@ -32,7 +32,7 @@ from vif_plug_ovs.tests.functional import base
 CONF = cfg.CONF
 
 
-@privsep.vif_plug.entrypoint
+@privsep.vif_plug_test.entrypoint
 def run_privileged(*full_args):
     return processutils.execute(*full_args)[0].rstrip()
 
@@ -81,26 +81,17 @@ class TestOVSDBLib(testscenarios.WithScenarios,
     def _list_ports_in_bridge(self, bridge):
         return self._ovsdb.list_ports(bridge).execute()
 
-    def _check_bridge(self, name):
-        return self._ovsdb.br_exists(name).execute()
-
-    def _add_bridge(self, name, may_exist=True, datapath_type=None):
-        self._ovsdb.add_br(name, may_exist=may_exist,
-                           datapath_type=datapath_type).execute()
-        self.assertTrue(self._check_bridge(name))
-
-    def _del_bridge(self, name):
-        self._ovsdb.del_br(name).execute()
-
     def test__set_mtu_request(self):
         port_name = 'port1-' + self.interface
         self._add_bridge(self.brname)
         self.addCleanup(self._del_bridge, self.brname)
         self._add_port(self.brname, port_name)
         if self.ovs._ovs_supports_mtu_requests():
-            self.ovs._set_mtu_request(port_name, 1000)
+            with self._ovsdb.transaction() as txn:
+                self.ovs._set_mtu_request(txn, port_name, 1000)
             self._check_parameter('Interface', port_name, 'mtu', 1000)
-            self.ovs._set_mtu_request(port_name, 1500)
+            with self._ovsdb.transaction() as txn:
+                self.ovs._set_mtu_request(txn, port_name, 1500)
             self._check_parameter('Interface', port_name, 'mtu', 1500)
         else:
             self.skipTest('Current version of Open vSwitch does not support '
